@@ -185,11 +185,12 @@ class Application(Gtk.Application):
         if not self.window:
             self.init()
             menu = self.__setup_app_menu()
-            if self.prefers_app_menu():
+            # If GNOME/Unity, add appmenu
+            if is_gnome() or is_unity():
                 self.set_app_menu(menu)
-                self.window = Window()
-            else:
-                self.window = Window()
+            self.window = Window()
+            # If not GNOME/Unity add menu to toolbar
+            if not is_gnome() and not is_unity():
                 self.window.setup_menu(menu)
             self.window.connect('delete-event', self.__hide_on_delete)
             self.window.init_list_one()
@@ -204,7 +205,7 @@ class Application(Gtk.Application):
                     from lollypop.charts import Charts
                     self.charts = Charts()
                     if get_network_available():
-                        self.charts.update()
+                        self.charts.start()
                 else:
                     self.settings.set_value('network-search',
                                             GLib.Variant('b', False))
@@ -277,11 +278,17 @@ class Application(Gtk.Application):
         try:
             from lollypop.radios import Radios
             with SqlCursor(self.db) as sql:
+                sql.isolation_level = None
                 sql.execute('VACUUM')
+                sql.isolation_level = ''
             with SqlCursor(self.playlists) as sql:
+                sql.isolation_level = None
                 sql.execute('VACUUM')
+                sql.isolation_level = ''
             with SqlCursor(Radios()) as sql:
+                sql.isolation_level = None
                 sql.execute('VACUUM')
+                sql.isolation_level = ''
         except Exception as e:
             print("Application::quit(): ", e)
         self.window.destroy()
@@ -453,7 +460,7 @@ class Application(Gtk.Application):
         self.settings.set_value('network-access', param)
         if self.charts is not None:
             if param.get_boolean():
-                self.charts.update()
+                self.charts.start()
             else:
                 self.charts.stop()
         self.window.reload_view()
