@@ -26,9 +26,15 @@ class BaseArt(GObject.GObject):
     """
         Base art manager
     """
-    _CACHE_PATH = GLib.get_home_dir() + "/.cache/lollypop"
+    if GLib.getenv("XDG_CACHE_HOME") is None:
+        _CACHE_PATH = GLib.get_home_dir() + "/.cache/lollypop"
+    else:
+        _CACHE_PATH = GLib.getenv("XDG_CACHE_HOME") + "/lollypop"
     # Fallback when album dir is readonly
-    _STORE_PATH = GLib.get_home_dir() + "/.local/share/lollypop/store"
+    if GLib.getenv("XDG_DATA_HOME") is None:
+        _STORE_PATH = GLib.get_home_dir() + "/.local/share/lollypop/store"
+    else:
+        _STORE_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop/store"
     __gsignals__ = {
         'album-artwork-changed': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         'artist-artwork-changed': (GObject.SignalFlags.RUN_FIRST,
@@ -110,10 +116,12 @@ class BaseArt(GObject.GObject):
                 # > 3.15 is missing savev method
                 try:
                     pixbuf.save(cache_path_jpg, "jpeg",
-                                ["quality"], ["90"])
+                                ["quality"], [str(Lp().settings.get_value(
+                                              'cover-quality').get_int32())])
                 except:
                     pixbuf.savev(cache_path_jpg, "jpeg",
-                                 ["quality"], ["90"])
+                                 ["quality"], [str(Lp().settings.get_value(
+                                              'cover-quality').get_int32())])
             surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale, None)
             del pixbuf
             return surface
@@ -136,6 +144,7 @@ class BaseArt(GObject.GObject):
         stream = Gio.MemoryInputStream.new_from_data(data,
                                                      None)
         cover = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
+        stream.close()
         cover_width = cover.get_width()
         cover_height = cover.get_height()
         del cover
