@@ -10,12 +10,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gio, GdkPixbuf
+from gi.repository import Gio, GLib, GdkPixbuf
 
 from os import mkdir, path, rename
 
 from lollypop.utils import escape
-from lollypop.define import ArtSize
+from lollypop.define import ArtSize, Lp
 from lollypop.lio import Lio
 
 
@@ -23,8 +23,15 @@ class InfoCache:
     """
         Generic class to cache text and images
     """
-    _INFO_PATH = path.expanduser("~") + "/.local/share/lollypop/info"
-    _CACHE_PATH = path.expanduser("~") + "/.cache/lollypop_info"
+    if GLib.getenv("XDG_DATA_HOME") is None:
+        _INFO_PATH = GLib.get_home_dir() + "/.local/share/lollypop/info"
+    else:
+        _INFO_PATH = GLib.getenv("XDG_DATA_HOME") + "/lollypop/info"
+    if GLib.getenv("XDG_CACHE_HOME") is None:
+        _CACHE_PATH = GLib.get_home_dir() + "/.cache/lollypop_info"
+    else:
+        _CACHE_PATH = GLib.getenv("XDG_CACHE_HOME") + "/lollypop_info"
+
     WEBSERVICES = [("lastfm", "_get_lastfm_artist_info",
                     "_get_lastfm_album_artwork"),
                    ("spotify", "_get_spotify_artist_info",
@@ -139,7 +146,8 @@ class InfoCache:
                                              0, 0)
                         del pixbuf
                     extract.savev(filepath_at_size, "jpeg",
-                                  ["quality"], ["90"])
+                                  ["quality"], [str(Lp().settings.get_value(
+                                                'cover-quality').get_int32())])
                     del extract
                 return filepath_at_size
         except Exception as e:
@@ -201,8 +209,10 @@ class InfoCache:
                                                                -1,
                                                                True,
                                                                None)
+            stream.close()
             pixbuf.savev(filepath+".jpg",
-                         "jpeg", ["quality"], ["90"])
+                         "jpeg", ["quality"], [str(Lp().settings.get_value(
+                                               'cover-quality').get_int32())])
             del pixbuf
 
     def remove(prefix, suffix):
