@@ -10,9 +10,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from threading import Thread
+from time import time
+
 from lollypop.charts_itunes import ItunesCharts
 from lollypop.charts_spotify import SpotifyCharts
-from lollypop.define import ChartsProvider, Lp
+from lollypop.charts_lastfm import LastfmCharts
+from lollypop.define import Lp
 
 
 class Charts:
@@ -24,23 +28,37 @@ class Charts:
         """
             Init charts
         """
-        if Lp().settings.get_enum('charts') == ChartsProvider.ITUNES:
-            self.__provider = ItunesCharts()
-        else:
-            self.__provider = SpotifyCharts()
+        self.__time = int(time())
+        self.__providers = [SpotifyCharts(self.__time),
+                            LastfmCharts(self.__time),
+                            ItunesCharts(self.__time)]
 
-    def update(self):
+    def start(self):
         """
-            Update charts
+            Start charts update
         """
-        self.__provider.update()
+        t = Thread(target=self.__update)
+        t.daemon = True
+        t.start()
 
     def stop(self):
         """
             Stop downloads
         """
-        self.__provider.stop()
+        for provider in self.__providers:
+            provider.stop()
 
 #######################
 # PRIVATE             #
 #######################
+    def __update(self):
+        """
+            Update charts
+            @thread safe
+        """
+        # Remove charts older than one week
+        t = self.__time - 604800
+        Lp().db.del_tracks(Lp().tracks.get_old_charts_track_ids(t))
+        # Update charts
+        for provider in self.__providers:
+            provider.update()
