@@ -154,24 +154,32 @@ class ArtistsDatabase:
                                  "SELECT DISTINCT artists.rowid,\
                                   artists.name, artists.sortname\
                                   FROM artists, albums,\
-                                  album_genres, album_artists\
+                                  album_genres AS AG, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
                                   AND album_artists.album_id=albums.rowid\
-                                  AND album_genres.album_id=albums.rowid\
-                                  AND album_genres.genre_id!=?\
+                                  AND AG.album_id=albums.rowid\
+                                  AND ? NOT IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres\
+                                    WHERE AG.album_id=album_genres.album_id)\
                                   ORDER BY artists.sortname\
                                   COLLATE NOCASE COLLATE LOCALIZED",
                                  (Type.CHARTS,))
             else:
-                genres = tuple(genre_ids)
+                genres = (Type.CHARTS,) + tuple(genre_ids)
                 request = "SELECT DISTINCT artists.rowid,\
                            artists.name, artists.sortname\
-                           FROM artists, albums, album_genres, album_artists\
+                           FROM artists, albums, album_genres AS AG,\
+                           album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
+                           AND ? NOT IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres\
+                                    WHERE AG.album_id=album_genres.album_id)\
                            AND albums.rowid=album_artists.album_id\
-                           AND album_genres.album_id=albums.rowid AND ("
+                           AND AG.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
-                    request += "album_genres.genre_id=? OR "
+                    request += "AG.genre_id=? OR "
                 request += "1=0) ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
                 result = sql.execute(request, genres)
