@@ -103,9 +103,16 @@ class GenresDatabase:
             @return [(id as int, name as string)]
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid, name FROM genres\
-                                  ORDER BY name\
-                                  COLLATE NOCASE COLLATE LOCALIZED")
+            result = sql.execute("SELECT DISTINCT genres.rowid, genres.name\
+                                  FROM genres,album_genres AS AG\
+                                  WHERE AG.genre_id=genres.rowid\
+                                  AND ? NOT IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres\
+                                    WHERE AG.album_id=album_genres.album_id)\
+                                  ORDER BY genres.name\
+                                  COLLATE NOCASE COLLATE LOCALIZED",
+                                 (Type.CHARTS,))
             return list(result)
 
     def get_ids(self):
@@ -114,11 +121,37 @@ class GenresDatabase:
             @return [id as int]
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM genres\
-                                  ORDER BY name\
-                                  COLLATE NOCASE COLLATE LOCALIZED")
+            result = sql.execute("SELECT DISTINCT genres.rowid\
+                                  FROM genres,album_genres AS AG\
+                                  WHERE AG.genre_id=genres.rowid\
+                                  AND ? NOT IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres\
+                                    WHERE AG.album_id=album_genres.album_id)\
+                                  ORDER BY genres.name\
+                                  COLLATE NOCASE COLLATE LOCALIZED",
+                                 (Type.CHARTS,))
             return list(itertools.chain(*result))
 
+    def get_charts(self, filter=Type.CHARTS):
+        """
+            Get genre for charts
+            @param filter as Type
+            @return [(id as int, name as string)]
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT DISTINCT genres.rowid, genres.name\
+                                  FROM genres,album_genres AS AG\
+                                  WHERE AG.genre_id=genres.rowid\
+                                  AND ? IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres\
+                                    WHERE AG.album_id=album_genres.album_id)\
+                                  ORDER BY genres.name\
+                                  COLLATE NOCASE COLLATE LOCALIZED",
+                                 (filter,))
+            return list(result)
+
     def clean(self, genre_id):
         """
             Clean database for genre id
