@@ -10,8 +10,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+import gi
+gi.require_version('Soup', '2.4')
+
 from gi.repository import Gio, GObject, Soup
 
+from lollypop.define import Lp
+
 
 class Lio:
     class File(GObject.Object, Gio.File):
@@ -44,5 +49,7 @@ class Lio:
                 else:
                     return Gio.File.load_contents(self, cancellable)
             except Exception as e:
-                print("Lio.load_contents()", e)
+                # FIXME Use debug, need to be moved outside utils.py
+                if Lp().debug:
+                    print("Lio.load_contents():",  e)
                 return (False, b'', "")
