@@ -145,7 +145,8 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             self._context.artist_ids[album.id] = list(album.artist_ids)
         self.shuffle_albums(True)
         if self._current_track.id is not None and self._current_track.id > 0:
-            self.set_next()
+            if not self.is_party:
+                self.set_next()
             self.set_prev()
         self.emit('album-added', album.id)
 
@@ -180,8 +181,9 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
                 self._albums.remove(album.id)
                 if album.id in self._albums_backup:
                     self._albums_backup.remove(album.id)
+            if not self.is_party or self._next_track.album_id == album.id:
+                self.set_next()
             self.set_prev()
-            self.set_next()
             self.emit('album-added', album.id)
         except Exception as e:
             print("Player::remove_album():", e)
@@ -307,6 +309,9 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         # We are in compilation view without genre
         elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
             self._albums = Lp().albums.get_compilation_ids()
+        # We are in charts view with a genre
+        elif artist_ids and artist_ids[0] == Type.CHARTS:
+            self._albums = Lp().albums.get_charts_ids(genre_ids)
         # Add albums for artists/genres
         else:
             # If we are not in compilation view and show compilation is on,
