@@ -14,6 +14,7 @@ from gi.repository import Gio, GLib, Gtk
 
 from gettext import gettext as _
 from threading import Thread
+from time import time
 
 from lollypop.widgets_rating import RatingWidget
 from lollypop.widgets_loved import LovedWidget
@@ -472,24 +473,6 @@ class TrackMenuPopover(Gtk.Popover):
         else:
             track_year = ""
 
-        rating = RatingWidget(track)
-        rating.set_margin_top(5)
-        rating.set_margin_bottom(5)
-        rating.set_property('halign', Gtk.Align.START)
-        rating.set_property('hexpand', True)
-        rating.show()
-
-        loved = LovedWidget(track)
-        loved.set_margin_end(5)
-        loved.set_margin_top(5)
-        loved.set_margin_bottom(5)
-        if track_year == "":
-            loved.set_property('halign', Gtk.Align.END)
-        else:
-            loved.set_property('halign', Gtk.Align.CENTER)
-        loved.set_property('hexpand', True)
-        loved.show()
-
         if track_year != "":
             year = Gtk.Label()
             year.set_text(track_year)
@@ -536,20 +519,41 @@ class TrackMenuPopover(Gtk.Popover):
             self.remove(menu_widget)
             grid.add(menu_widget)
 
-        if not track.album.is_web:
-            separator = Gtk.Separator()
-            separator.show()
-            grid.add(separator)
-
         hgrid = Gtk.Grid()
-        hgrid.add(rating)
-        hgrid.add(loved)
-        if track.album.is_web:
-            hgrid.add(web)
-            hgrid.add(search)
-        if track_year != "":
-            hgrid.add(year)
-        hgrid.show()
+        if Type.CHARTS not in track.genre_ids:
+            if not track.album.is_web:
+                separator = Gtk.Separator()
+                separator.show()
+                grid.add(separator)
+
+            rating = RatingWidget(track)
+            rating.set_margin_top(5)
+            rating.set_margin_bottom(5)
+            rating.set_property('halign', Gtk.Align.START)
+            rating.set_property('hexpand', True)
+            rating.show()
+
+            loved = LovedWidget(track)
+            loved.set_margin_end(5)
+            loved.set_margin_top(5)
+            loved.set_margin_bottom(5)
+            if track_year == "":
+                loved.set_property('halign', Gtk.Align.END)
+            else:
+                loved.set_property('halign', Gtk.Align.CENTER)
+            loved.set_property('hexpand', True)
+            loved.show()
+
+            hgrid.add(rating)
+            hgrid.add(loved)
+
+            if track.album.is_web:
+                hgrid.add(web)
+                hgrid.add(search)
+            if track_year != "":
+                hgrid.add(year)
+            hgrid.show()
+
         if track.album.is_web:
             grid.set_row_spacing(2)
             uri = Lp().tracks.get_uri(track.id)
@@ -599,7 +603,7 @@ class AlbumMenuPopover(Gtk.Popover):
         edit.set_margin_bottom(5)
         edit.set_property('hexpand', True)
         edit.set_property('halign', Gtk.Align.CENTER)
-        genres = ", ".join(Lp().albums.get_genres(album.id))
+        genres = ";".join(Lp().albums.get_genres(album.id))
         if not genres:
             genres = "Web"
         edit.set_text(genres)
@@ -654,21 +658,23 @@ class AlbumMenuPopover(Gtk.Popover):
             @param edit as Gtk.Edit
             @param album as Album
         """
-        genre = edit.get_text()
-        if not genre:
+        genres = edit.get_text()
+        if not genres:
             return
         orig_genre_ids = Lp().albums.get_genre_ids(album.id)
-        genre_id = Lp().genres.get_id(genre)
-        if genre_id is None:
-            genre_id = Lp().genres.add(genre)
-            Lp().scanner.emit('genre-updated', genre_id, True)
         Lp().albums.del_genres(album.id)
-        Lp().albums.add_genre(album.id, genre_id)
         for track_id in album.track_ids:
-            Lp().tracks.del_genres(track_id)
-            Lp().tracks.add_genre(track_id, genre_id)
+                Lp().tracks.del_genres(track_id)
+        for genre in genres.split(";"):
+            genre_id = Lp().genres.get_id(genre)
+            if genre_id is None:
+                genre_id = Lp().genres.add(genre)
+                Lp().scanner.emit('genre-updated', genre_id, True)
+            Lp().albums.add_genre(album.id, genre_id, int(time()))
+            for track_id in album.track_ids:
+                Lp().tracks.add_genre(track_id, genre_id, int(time()))
         for genre_id in orig_genre_ids:
-            if genre_id != Type.CHARTS:
+            if genre_id >= 0:
                 Lp().genres.clean(genre_id)
                 GLib.idle_add(Lp().scanner.emit, 'genre-updated',
                               genre_id, False)
