@@ -18,7 +18,6 @@ from threading import Thread
 from lollypop.define import Lp, ArtSize, Type, DbPersistent
 from lollypop.objects import Track, Album
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
-from lollypop.pop_album import AlbumPopover
 from lollypop.view_albums import AlbumBackView
 from lollypop.utils import noaccents, get_network_available
 from lollypop.lio import Lio
@@ -321,7 +320,6 @@ class SearchPopover(Gtk.Popover):
         self.__entry = builder.get_object('entry')
 
         self.__view = Gtk.ListBox()
-        self.__view.set_sort_func(self.__sort_func)
         self.__view.connect("button-press-event", self.__on_button_press)
         self.__view.connect("row-activated", self.__on_row_activated)
         self.__view.set_selection_mode(Gtk.SelectionMode.NONE)
@@ -336,7 +334,9 @@ class SearchPopover(Gtk.Popover):
             self.__switch.set_tooltip_text(_("You need to install youtube-dl"))
         else:
             self.__switch.set_state(Lp().settings.get_value('network-search'))
-        builder.get_object('scrolled').add(self.__view)
+
+        self.__scrolled = builder.get_object('scrolled')
+        self.__scrolled.add(self.__view)
         # Connect here because we don't want previous switch.set_state()
         # to emit a signal on init
         builder.connect_signals(self)
@@ -469,6 +469,7 @@ class SearchPopover(Gtk.Popover):
             Populate searching items
             in db based on text entry current text
         """
+        self.__view.set_sort_func(None)
         self.__header_stack.set_visible_child(self.__spinner)
         self.__spinner.start()
         self.__history = []
@@ -576,6 +577,9 @@ class SearchPopover(Gtk.Popover):
                     (self.__nsearch is None or self.__nsearch.finished):
                 self.__header_stack.set_visible_child(self.__new_btn)
                 self.__spinner.stop()
+                # Prevent jumping UI
+                if self.__scrolled.get_vadjustment().get_value() == 0:
+                    self.__view.set_sort_func(self.__sort_func)
             return
         item = search.items.pop(0)
         search_row = SearchRow(item)
@@ -593,9 +597,12 @@ class SearchPopover(Gtk.Popover):
             if self.__nsearch.finished and self.__lsearch.finished:
                 self.__header_stack.set_visible_child(self.__new_btn)
                 self.__spinner.stop()
+                # Prevent jumping UI
+                if self.__scrolled.get_vadjustment().get_value() == 0:
+                    self.__view.set_sort_func(self.__sort_func)
             return
         item = search.items.pop(0)
-        if item.exists_in_db():
+        if item.exists_in_db()[0]:
             return
         if item.is_track:
             history = "♫" + item.name + item.artists[0]
@@ -699,9 +706,3 @@ class SearchPopover(Gtk.Popover):
                 popover.set_relative_to(widget)
                 popover.set_pointing_to(rect)
                 popover.show()
-            else:
-                popover = AlbumPopover(row.id, [],
-                                       row.artist_ids)
-                popover.set_relative_to(widget)
-                popover.set_pointing_to(rect)
-                popover.show()
