@@ -91,7 +91,7 @@ class TuneinPopover(Gtk.Popover):
         self.__current_url = url
         self.__back_btn.set_sensitive(False)
         self.__home_btn.set_sensitive(False)
-        self.__label.set_text(_("Please wait..."))
+        self.__label.set_text(_("Please wait…"))
         t = Thread(target=self.__populate, args=(url,))
         t.daemon = True
         t.start()
@@ -178,7 +178,7 @@ class TuneinPopover(Gtk.Popover):
                     GLib.idle_add(self.__show_not_found)
         except:
             GLib.idle_add(self.__show_not_found,
-                          _("Can't connect to TuneIn..."))
+                          _("Can't connect to TuneIn…"))
 
     def __add_items(self, items, url):
         """
@@ -272,18 +272,23 @@ class TuneinPopover(Gtk.Popover):
             @param image as Gtk.Image
             @param stream as Gio.MemoryInputStream
         """
-        pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
-                                                           ArtSize.MEDIUM,
-                                                           ArtSize.MEDIUM,
-                                                           True,
+        try:
+            # Strange issue #969, stream is None
+            # But there is a check in __download_images()
+            pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
+                                                               ArtSize.MEDIUM,
+                                                               ArtSize.MEDIUM,
+                                                               True,
+                                                               None)
+            stream.close()
+            surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf,
+                                                           0,
                                                            None)
-        stream.close()
-        surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf,
-                                                       0,
-                                                       None)
-        del pixbuf
-        image.set_from_surface(surface)
-        del surface
+            del pixbuf
+            image.set_from_surface(surface)
+            del surface
+        except Exception as e:
+            print("TuneinPopover::__set_image():", e)
 
     def __clear(self):
         """
