@@ -46,11 +46,13 @@ class ItunesSearch:
                 for item in decode['results']:
                     if item['trackName'].lower() in tracks:
                         continue
+                    album_item = SearchItem()
+                    album_item.name = item['collectionName']
                     search_item = SearchItem()
                     search_item.is_track = True
                     search_item.name = item['trackName']
                     tracks.append(search_item.name.lower())
-                    search_item.album = item['collectionName']
+                    search_item.album = album_item
                     search_item.tracknumber = int(item['trackNumber'])
                     search_item.discnumber = int(item['discNumber'])
                     search_item.duration = int(item['trackTimeMillis']) / 1000
@@ -92,8 +94,7 @@ class ItunesSearch:
             # For each album, get cover and tracks
             for item in decode['results']:
                 album_item = SearchItem()
-                album_item.name = album_item.album_name =\
-                    item['collectionName']
+                album_item.name = item['collectionName']
                 album_item.is_track = False
                 album_item.artists = [item['artistName']]
                 album_item.cover = item['artworkUrl60'].replace('60x60',
@@ -116,7 +117,7 @@ class ItunesSearch:
                     except:
                         pass  # May be missing
                     track_item.name = item['trackName']
-                    track_item.album = album_item.name
+                    track_item.album = album_item
                     track_item.tracknumber = int(item['trackNumber'])
                     track_item.discnumber = int(item['discNumber'])
                     track_item.duration = int(item['trackTimeMillis'])\
