@@ -46,11 +46,13 @@ class SpotifySearch:
                 for item in decode['tracks']['items']:
                     if item['name'].lower() in tracks:
                         continue
+                    album_item = SearchItem()
                     search_item = SearchItem()
                     search_item.is_track = True
                     search_item.name = item['name']
+                    album_item.name = item['name']
+                    search_item.album = album_item
                     tracks.append(search_item.name.lower())
-                    search_item.album = item['album']['name']
                     search_item.tracknumber = int(item['track_number'])
                     search_item.discnumber = int(item['disc_number'])
                     search_item.duration = int(item['duration_ms']) / 1000
@@ -101,7 +103,7 @@ class SpotifySearch:
             if status:
                 decode = json.loads(data.decode('utf-8'))
                 album_item = SearchItem()
-                album_item.name = album_item.album_name = decode['name']
+                album_item.name = decode['name']
                 album_item.cover = decode['images'][0]['url']
                 album_item.smallcover = decode['images'][2]['url']
                 album_item.ex_id = album_id
@@ -131,6 +133,42 @@ class SpotifySearch:
             print("SpotifySearch::get_album:", e)
         return None
 
+    def get_track(self, track_id):
+        """
+            Return spotify track as SearchItem
+            @param track id as str
+            @return SearchItem
+        """
+        try:
+            s = Lio.File.new_for_uri("https://api.spotify.com/v1/"
+                                     "tracks/%s" % track_id)
+            (status, data, tag) = s.load_contents(self._cancel)
+            if status:
+                decode = json.loads(data.decode('utf-8'))
+                album_item = SearchItem()
+                album_item.name = decode['album']['name']
+                album_item.cover = decode['album']['images'][0]['url']
+                album_item.smallcover = decode['album']['images'][2]['url']
+
+                track_item = SearchItem()
+                track_item.is_track = True
+                track_item.name = decode['name']
+                track_item.album = album_item
+                track_item.tracknumber = int(
+                                          decode['track_number'])
+                track_item.discnumber = int(
+                                           decode['disc_number'])
+                track_item.duration = int(
+                                    decode['duration_ms']) / 1000
+                for artist in decode['artists']:
+                    track_item.artists.append(artist['name'])
+                album_item.artists = track_item.artists
+                album_item.subitems.append(track_item)
+                return album_item
+        except Exception as e:
+            print("SpotifySearch::get_track", e)
+        return None
+
 #######################
 # PRIVATE             #
 #######################
@@ -167,8 +205,7 @@ class SpotifySearch:
                             if item['name'].lower() in albums:
                                 continue
                             album_item = SearchItem()
-                            album_item.name = album_item.album_name = item[
-                                                                        'name']
+                            album_item.name = item['name']
                             albums.append(album_item.name.lower())
                             album_item.cover = item['images'][0]['url']
                             album_item.smallcover = item['images'][2]['url']
@@ -186,7 +223,7 @@ class SpotifySearch:
                                 track_item = SearchItem()
                                 track_item.is_track = True
                                 track_item.name = item['name']
-                                track_item.album = album_item.name
+                                track_item.album = album_item
                                 try:
                                     track_item.year = decode[
                                                             'release_date'][:4]
@@ -225,7 +262,7 @@ class SpotifySearch:
                 # For each album, get cover and tracks
                 for item in decode['albums']['items']:
                     album_item = SearchItem()
-                    album_item.name = album_item.album_name = item['name']
+                    album_item.name = item['name']
                     album_item.is_track = False
                     album_item.cover = item['images'][0]['url']
                     album_item.smallcover = item['images'][2]['url']
@@ -243,7 +280,7 @@ class SpotifySearch:
                             except:
                                 pass  # May be missing
                             track_item.name = item['name']
-                            track_item.album = album_item.name
+                            track_item.album = album_item
                             track_item.tracknumber = int(item['track_number'])
                             track_item.discnumber = int(item['disc_number'])
                             track_item.duration = int(item['duration_ms'])\
