@@ -433,6 +433,12 @@ class SelectionList(Gtk.Overlay):
             icon = 'document-new-symbolic'
         elif object_id == Type.CHARTS:
             icon = 'application-rss+xml-symbolic'
+        elif object_id == Type.SPOTIFY:
+            icon = 'lollypop-spotify-symbolic'
+        elif object_id == Type.ITUNES:
+            icon = 'lollypop-itunes-symbolic'
+        elif object_id == Type.LASTFM:
+            icon = 'lollypop-lastfm-symbolic'
         return icon
 
     def __sort_items(self, model, itera, iterb, data):
