@@ -360,7 +360,7 @@ class SettingsDialog:
                 from lollypop.charts import Charts
                 Lp().charts = Charts()
             if get_network_available():
-                Lp().charts.update()
+                Lp().charts.start()
             elif Lp().notify is not None:
                 Lp().notify.send(_("The charts"),
                                  _("Network access disabled"))
@@ -577,6 +577,8 @@ class SettingsDialog:
             self.__reset_button.get_toplevel().set_deletable(False)
             self.__reset_button.set_sensitive(False)
             self.__infobar.hide()
+            if Lp().charts is not None:
+                Lp().charts.stop()
             self.__reset_database(track_ids, len(track_ids), history)
         except Exception as e:
             print("Application::_on_confirm_button_clicked():", e)
@@ -783,6 +785,8 @@ class SettingsDialog:
             Lp().window.show_genres(Lp().settings.get_value('show-genres'))
             Lp().window.update_db()
             self.__progress.get_toplevel().set_deletable(True)
+            if Lp().charts is not None and get_network_available():
+                Lp().charts.start()
 
 
 class ChooserWidget(Gtk.Grid):
