@@ -15,12 +15,10 @@ from gi.repository import Gio, GLib
 from gettext import gettext as _
 from threading import Thread
 import unicodedata
-import socket
-import fcntl
-import struct
 
 from lollypop.define import Lp, Type
 from lollypop.objects import Track
+from lollypop.lio import Lio
 
 
 def get_network_available():
@@ -62,17 +60,6 @@ def debug(str):
         print(str)
 
 
-def get_ip(interface):
-    """
-        Get ip address for interface
-    """
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    return socket.inet_ntoa(fcntl.ioctl(
-        s.fileno(),
-        0x8915,  # SIOCGIFADDR
-        struct.pack('256s', interface[:15].encode('utf-8')))[20:24])
-
-
 def is_unity():
     """
         Return True if desktop is Unity
@@ -96,6 +83,7 @@ def is_audio(f):
         info = f.query_info('standard::content-type',
                             Gio.FileQueryInfoFlags.NONE)
         if info is not None:
+            # Issue with GLib mime detection, should detect mp4 audio as audio
             if info.get_content_type()[0:6] == "audio/" or\
                info.get_content_type() == "video/mp4":
                 return True
@@ -165,7 +153,7 @@ def is_readonly(uri):
     """
         Check if uri is readonly
     """
-    f = Gio.File.new_for_uri(uri)
+    f = Lio.File.new_for_uri(uri)
     info = f.query_info('access::can-write',
                         Gio.FileQueryInfoFlags.NONE,
                         None)
