@@ -13,6 +13,7 @@
 from gi.repository import Gtk, GLib
 
 from lollypop.view_device import DeviceView
+from lollypop.utils import debug
 
 
 class ViewContainer(Gtk.Stack):
@@ -37,15 +38,12 @@ class ViewContainer(Gtk.Stack):
             @param view as new View
         """
         for child in self.get_children():
-            if child != view:
-                if not isinstance(child, DeviceView):
-                    if hasattr(child, "stop"):
-                        child.stop()
-                    # Delayed destroy as we may have an animation running
-                    # Gtk.StackTransitionType.CROSSFADE
-                    GLib.timeout_add(self.__duration*5,
-                                     self.__delayedclean_view,
-                                     child)
+            if child != view and not isinstance(child, DeviceView):
+                # Delayed destroy as we may have an animation running
+                # Gtk.StackTransitionType.CROSSFADE
+                GLib.timeout_add(self.__duration*5,
+                                 self.__delayedclean_view,
+                                 child)
 
 #######################
 # PRIVATE             #
@@ -55,4 +53,5 @@ class ViewContainer(Gtk.Stack):
             Clean view
             @param valid view as View
         """
+        debug("ViewContainer::__delayedclean_view(): %s" % view)
         view.destroy()
