@@ -39,7 +39,8 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         Gtk.FlowBoxChild.__init__(self)
         self.set_size_request(ArtSize.BIG, ArtSize.BIG)
         self.get_style_context().add_class('loading')
-        AlbumWidget.__init__(self, album_id, genre_ids, artist_ids)
+        AlbumWidget.__init__(self, album_id, genre_ids,
+                             artist_ids, ArtSize.BIG)
 
     def populate(self):
         """
@@ -106,8 +107,9 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             Return preferred width
             @return (int, int)
         """
-        # Padding: 3px, border: 1px + spacing
-        width = ArtSize.BIG + 14
+        if self._widget is None:
+            return (0, 0)
+        width = Gtk.FlowBoxChild.do_get_preferred_width(self)[0]
         return (width, width)
 
 #######################
